/*
 *  Copyright (c) 2011 Nicholas Okunew
 *  All rights reserved.
 *  
 *  This file is part of the com.atomicleopard.expressive library
 *  
 *  The com.atomicleopard.expressive library is free software: you 
 *  can redistribute it and/or modify it under the terms of the GNU
 *  Lesser General Public License as published by the Free Software Foundation, 
 *  either version 3 of the License, or (at your option) any later version.
 *  
 *  The com.atomicleopard.expressive library is distributed in the hope
 *  that it will be useful, but WITHOUT ANY WARRANTY; without even
 *  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *  See the GNU Lesser General Public License for more details.
 *  
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with the com.atomicleopard.expressive library.  If not, see 
 *  http://www.gnu.org/licenses/lgpl-3.0.html.
 */
package com.atomicleopard.expressive;

/**
 * Utility class which provides casting operations.
 * 
 * <p>
 * {@link #as(Object, Class)} performs a cast operation, returning null if a
 * cast is not valid. <br/>
 * This allows illegal cast syntax to be more elegant and brief - a null check
 * as opposed to a try/catch.<br/>
 * </p>
 * 
 */
@SuppressWarnings("unchecked")
public final class Cast {
	Cast() {
	}

	/**
	 * <p>
	 * Performs a cast operation of the parameter t to the type defined by the
	 * class s, or null if no legal cast can be made.
	 * </p>
	 * <p>
	 * This allows illegal cast syntax to be more elegant and brief - a null
	 * check as opposed to a try/catch.
	 * </p>
	 * 
	 * @param <S>
	 * @param <T>
	 * @param t
	 *            object to cast
	 * @param s
	 *            Class to cast the parameter t to
	 * @return t cast to the type of S, or null if this is not a legal cast.
	 */
	public static <S, T> S as(T t, Class<S> s) {
		if (s.isAssignableFrom(t.getClass())) {
			return (S) t;
		}
		return null;
	}
}
